@@ -1004,7 +1004,7 @@ class NumerousAdminClient(NumerousClient):
         self._base_client.UpdateExecution(spm_pb2.Json(json=json.dumps(update_)))
 
     def get_execution_status(self, exe_id):
-        return self._base_client.GetExecutionStatus(spm_pb2.ExecutionId(execution_id=exe_id)).json
+        return self._job_manager.GetExecutionStatus(spm_pb2.ExecutionId(execution_id=exe_id)).json
 
 
 @contextmanager
